/* USB interface command definitions V2.0 (13.08.2005) */
/*
// Copyright (c) 2005 Oliver Bartels F+E, Erding / All Rights reserved
//
// DESCRIPTION
//
// This file contains the USB interface command and status definitions.
*/

/* Avoid multiple inclusion */
#ifndef INCLUDE_USBCMDDEFS
#define INCLUDE_USBCMDDEFS

/*________________________________________________________________*/
/* USB interface definitions */

/* USB protocol constants */
#define USB_DBLKSIZE	0x100		/* USB max. data blcok size */

/* USB commands */
#define UCMD_NOP	0x00		/* USB NOP command */
#define UCMD_IDREQ	0x01		/* USB identification request */
#define UCMD_LOGOUT	0x02		/* USB log out */
#define UCMD_FILEREAD	0x10		/* USB file read command */
#define UCMD_FILEWRITE	0x11		/* USB file write command */
#define UCMD_FILEDEL	0x12		/* USB file delete command */
#define UCMD_FTMAXSIZE	0x13		/* USB file transfer max. size cmd. */
#define UCMD_GETSTPVAR	0x20		/* UDB get setup variable */
#define UCMD_SETSTPVAR	0x21		/* UDB set setup variable */
#define UCMD_FLSTART	0xE0		/* USB flash start command */
#define UCMD_FLCLEAR	0xE1		/* USB flash clear command */
#define UCMD_FLERASE	0xE2		/* USB flash erase command */
#define UCMD_FLPROG	0xE3		/* USB flash program command */
#define UCMD_FLEXIT	0xE4		/* USB flash loader exit command */
#define UCMD_FLPOWOFF	0xE5		/* USB flash loader power off cmd. */

/* USB status replies */
#define UST_NOP		0x00		/* USB NOP command */
#define UST_IDACK	0x01		/* USB identification ack. */
#define UST_FILESTAT	0x10		/* USB file handling status */
#define UST_FTMAXSIZE	0x11		/* USB file transfer max. size */
#define UST_FTREADDAT	0x12		/* USB file transfer read data */
#define UST_GETSTPRES	0x20		/* USB get setup var. result */
#define UST_SETSTPRES	0x21		/* USB set setup var. result */
#define UST_AMPFREQDAT	0x22		/* USB amplitude frequency data */
#define UST_FLMODEREP	0xE0		/* USB flash mode report */
#define UST_FLSTAT	0xE1		/* USB flash status */

/* USB identification codes */
#define UIDREQ_CODE1	0xA5		/* USB id. request code 1 */
#define UIDREQ_CODE2	0x5A		/* USB id. request code 2 */
#define UIDREQ_CODE3	0xF1		/* USB id. request code 3 */
#define UIDREQ_CODE4	0x1F		/* USB id. request code 4 */
#define UIDACK_CODE1	0x51		/* USB id. ack. code 1 */
#define UIDACK_CODE2	0x1A		/* USB id. ack. code 2 */
#define UIDACK_CODE3	0xF5		/* USB id. ack. code 3 */
#define UIDACK_CODE4	0xAF		/* USB id. ack. code 4 */

/* USB file handling status codes */
#define UFST_DONE	0x00		/* File operation done */
#define UFST_NOTFND	0x01		/* File or section not found error */
#define UFST_FSFULL	0x02		/* File system full error */
#define UFST_ACCERR	0x03		/* File system access error */

/* USB setup variable handling status codes */
#define USST_DONE	0x00		/* Setup var. operation done */
#define USST_FAILED	0x01		/* Setup var. operation failed */

/* USB flash mode codes */
#define UFMODE_APPL	0x00		/* USB within application */
#define UFMODE_LOADER	0x01		/* USB within flash loader */

/*________________________________________________________________*/
/* Conditional file inclusion end */
#endif	/* INCLUDE_USBCMDDEFS */

/* Include file end */
