/* Bartels LCS Spec Software V1.0 (17.08.2005) */

/* (C) 2005 Oliver Bartels F+E, Erding */

/* usbconnector.h : USB Connector include */

/* space for handle (type is not used here) */
#define FT_HANDLE_SIZE 16
/* maximum number of entries for measurement values */
#define MAXDATABUFFER 512
#define MAXDEVICENAMELEN 32
#define DEBUGLEN 512

struct Smeasurementvalue {
	unsigned int time;		/* current kHz Timer value */
	unsigned int freq;		/* frequency / 10 */
	float minval;			/* minimum value of measurement point */
	float maxval;			/* maximum value of measurement point */
};

extern void __cdecl readerthreadfunc(void * instance);

class Cusbconnection
{
/* Constructor / Destructor */
protected:
	Cusbconnection();
	~Cusbconnection();
	enum Eerrorstate {		/* state when error occured */
		NONE,
		OPEN,
		LISTDEVICES,
		CHECKDEVICE,
		SETUPDEVICE,
		CLOSE,
		READ,
		READCMDCODE,
		READCMDLEN,
		READTIMEOUT,
		CMDSYNCWAIT,
		NOTUNIQUE,
		NOTFOUND,
		WRITE,
	};
	friend void __cdecl readerthreadfunc(void * instance);
/* measurement data interface */
public:
	/* start reader */
	int startreader(HWND wnd, int msg, int pollintervall);
	/* stop reader */
	int stopreader();
	/* pause reader (until resume) */
	int pausereader();
	/* resume stopped reader */
	int resumereader();
	/* get buffered data */
	int readdata(Smeasurementvalue * buf, int count);
	/* check reader state */
	int getreaderstate();
/* command interface */
public:
	/* read data */
	int read(void * output, int len, int block = 1);
	int readcmd(void * output, int cmd, int len = -1);
	/* write data */
	int write(const void * data, int len);
	int writebytes(int b1, int b2 = -1, int b3 = -1, int b4 = -1, int b5 = -1);
	int writecmdwords(int cmd, int b2 = -1, int b3 = -1, int b4 = -1);
	int writeuint(const unsigned int data);
	int writeushort(const unsigned short data);
	int writeuchar(const unsigned char data);
	/* read environment value */
	int readenvironment(int id, float & value);
	/* write environtment value */
	int writeenvironment(int id, float value);
	/* set timeout */
	int setmaxtimeout(int milliseconds);
	/* abort current operation */
	static void abort();
/* Query Interface */
public:
	/* get a connection by id */
	static Cusbconnection * getconnection(const char * name);
	/* close all connections */
	static void closeall();
	/* get error description */
	const char * geterrorstate();
	/* activate debugging / get debug text */
	void setdebug(int flag);
	const char * getdebug();
	/* verfiy gadget id */
	int verifyid(int force = 0);
	/* get name of connected device */
	const char * getdevicename();
/* internal operations */
protected:
	int doopen(const char * name);
	int doclose();
	/* store error state */
	void seterrorstate(int state, int status);
	/* get command length by command */
	int getcmdlen(int cmd, int len);
	/* run reader thread */
	int runreaderthread(int * terminate);
/* object data */
protected:
	int m_state;		/* open state, 0 == close */
	int m_errorstate;	/* error state */
	int m_errorcode;	/* last error code */
	int m_timeoutcount;	/* number of read cycles for timeout */
	/* handle data */
	unsigned char m_handledata[FT_HANDLE_SIZE];
	char m_debugtxt[DEBUGLEN];
	int m_debuglen;
	Smeasurementvalue m_valbuf[MAXDATABUFFER];	/* buffer for data */
	int m_bufstart;					/* start of ring buffer */
	int m_bufend;					/* end of ring buffer */
	int m_readerstate;				/* reader state
										0: stopped,
										1: running,
										2: paused */
	int m_pollinterval;				/* interval for reader */
	int m_readertimermsgid;			/* timer id to send to the window */
	HWND m_readerwnd;				/* handle to collector window */
	HANDLE m_mutex;					/* reader thread mutex */
	int * m_terminatereader;		/* pointer to terminate reader flag */
	int m_readerdelay;				/* delay in ms to call the reader */
	int m_readertimerid;			/* id of the timer to kill him */
	int m_readerflushlen;			/* length of buffer when to flush */
	char m_devicename[MAXDEVICENAMELEN];	/* connected device */
/* static object data */
protected:
	/* list of instances by id */
	static Cusbconnection * m_instance;
	static int m_abortflag;
};
